@@ -66,9 +66,8 @@ class Freebox(IPlugin):
 					for bar in range(lg):
 ##				#	while i = rs['idx_sec']:
 ##						for i in rs['idx_sec']:
-##								if rs['idx'][i - rang] == '|':
-##									rangs.append(rang)
-##									log.msg(" rang  :  %s" % (rangs))
+						if rs['idx'][bar] == '|':
+							log.msg(" bar  :  %s" % (bar))
 #>>> for rang in range(len(mot)):  # La variable rang parcourt les entiers de 0 au rang de la dernière lettre du mot.
 #...     if mot[rang] == 'i':
 #...         rangs.append(rang)    # Si la lettre du mot est 'i', on stocke le rang dans notre liste.
@@ -76,10 +75,11 @@ class Freebox(IPlugin):
 #[5, 7]
 ##							# search position '|' dans rs['idx']	
 ##							# 'http://hd2.freebox.fr/pub/remote_control?code=35782633&key=%s' % (rs))
-							for rx in rs['idx_sec']:
-								log.msg(" rx  :  %s" % (rx))
-								log.msg("idx_sec  :  %s" % rs['idx_sec'])
-								log.msg("idx  :  %s" % (rs['idx']))
+##							for rx in rs['idx_sec']:
+##								log.msg(" rx  :  %s" % (rx))
+##								log.msg("idx_sec  :  %s" % rs['idx_sec'])
+##								log.msg("idx  :  %s" % (rs['idx']))
+##
 								resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
 							log.msg("resp  :  %s" % (resp))
 				if rs['idx_sec'] == "1":
